aboutsummaryrefslogtreecommitdiffstats
path: root/build_scripts
diff options
context:
space:
mode:
authorFriedemann Kleint <Friedemann.Kleint@qt.io>2020-10-28 07:51:22 +0100
committerFriedemann Kleint <Friedemann.Kleint@qt.io>2020-10-28 09:34:35 +0000
commit2a2a0827fa54b2eeb48e0e2090dfc503492ef33e (patch)
tree4311f7ad34ff98fabcbe4c34e59a970ae4ff4bcf /build_scripts
parentfb1c0f204e09ba29fa3d360d72231d4ed468c1e4 (diff)
Rename shiboken2 to shiboken6
Adapt CMake files, build scripts, tests and examples. Task-number: PYSIDE-904 Change-Id: I4cb5ee4c8df539546014b08202a7b1e98ed3ff07 Reviewed-by: Cristian Maureira-Fredes <cristian.maureira-fredes@qt.io>
Diffstat (limited to 'build_scripts')
-rw-r--r--build_scripts/config.py34
-rw-r--r--build_scripts/main.py28
-rw-r--r--build_scripts/platforms/linux.py2
-rw-r--r--build_scripts/platforms/unix.py10
-rw-r--r--build_scripts/platforms/windows_desktop.py14
-rw-r--r--build_scripts/setup_runner.py2
6 files changed, 45 insertions, 45 deletions
diff --git a/build_scripts/platforms/linux.py b/build_scripts/platforms/linux.py
index 712739e05..ddfd8e21a 100644
--- a/build_scripts/platforms/linux.py
+++ b/build_scripts/platforms/linux.py
@@ -85,7 +85,7 @@ def prepare_standalone_package_linux(self, vars):
# which ICU libs are used by QtCore (if used at all) using a
# custom written ldd, and copy the ICU libs to the Pyside Qt
# dir if necessary. We choose the QtCore lib to inspect, by
- # checking which QtCore library the shiboken2 executable uses.
+ # checking which QtCore library the shiboken6 executable uses.
if not maybe_icu_libs:
copy_icu_libs(self._patchelf_path, resolved_destination_lib_dir)
diff --git a/build_scripts/platforms/unix.py b/build_scripts/platforms/unix.py
index 30fa237c7..1e1c1e4a8 100644
--- a/build_scripts/platforms/unix.py
+++ b/build_scripts/platforms/unix.py
@@ -72,11 +72,11 @@ def prepare_packages_posix(self, vars):
return name + postfix
if config.is_internal_shiboken_module_build():
- # <build>/shiboken2/doc/html/* ->
- # <setup>/{st_package_name}/docs/shiboken2
+ # <build>/shiboken6/doc/html/* ->
+ # <setup>/{st_package_name}/docs/shiboken6
copydir(
- "{build_dir}/shiboken2/doc/html",
- "{st_build_dir}/{st_package_name}/docs/shiboken2",
+ "{build_dir}/shiboken6/doc/html",
+ "{st_build_dir}/{st_package_name}/docs/shiboken6",
force=False, vars=vars)
# <install>/lib/lib* -> {st_package_name}/
@@ -95,7 +95,7 @@ def prepare_packages_posix(self, vars):
"{install_dir}/bin/",
"{st_build_dir}/{st_package_name}",
filter=[
- "shiboken2",
+ "shiboken6",
],
recursive=False, vars=vars))
diff --git a/build_scripts/platforms/windows_desktop.py b/build_scripts/platforms/windows_desktop.py
index 77bf9bfd2..83485e1d7 100644
--- a/build_scripts/platforms/windows_desktop.py
+++ b/build_scripts/platforms/windows_desktop.py
@@ -66,11 +66,11 @@ def prepare_packages_win32(self, vars):
vars=vars)
if config.is_internal_shiboken_module_build():
- # <build>/shiboken2/doc/html/* ->
- # <setup>/{st_package_name}/docs/shiboken2
+ # <build>/shiboken6/doc/html/* ->
+ # <setup>/{st_package_name}/docs/shiboken6
copydir(
- "{build_dir}/shiboken2/doc/html",
- "{st_build_dir}/{st_package_name}/docs/shiboken2",
+ "{build_dir}/shiboken6/doc/html",
+ "{st_build_dir}/{st_package_name}/docs/shiboken6",
force=False, vars=vars)
# <install>/bin/*.dll -> {st_package_name}/
@@ -91,14 +91,14 @@ def prepare_packages_win32(self, vars):
# {shibokengenerator}.pdb file.
# Task-number: PYSIDE-615
copydir(
- "{build_dir}/shiboken2/shibokenmodule",
+ "{build_dir}/shiboken6/shibokenmodule",
"{st_build_dir}/{st_package_name}",
filter=pdbs,
recursive=False, vars=vars)
# pdb files for libshiboken and libpyside
copydir(
- "{build_dir}/shiboken2/libshiboken",
+ "{build_dir}/shiboken6/libshiboken",
"{st_build_dir}/{st_package_name}",
filter=pdbs,
recursive=False, vars=vars)
@@ -126,7 +126,7 @@ def prepare_packages_win32(self, vars):
# {shibokenmodule}.pdb file.
# Task-number: PYSIDE-615
copydir(
- "{build_dir}/shiboken2/generator",
+ "{build_dir}/shiboken6/generator",
"{st_build_dir}/{st_package_name}",
filter=pdbs,
recursive=False, vars=vars)
diff --git a/build_scripts/setup_runner.py b/build_scripts/setup_runner.py
index 6b944c2c8..3b6c6e117 100644
--- a/build_scripts/setup_runner.py
+++ b/build_scripts/setup_runner.py
@@ -129,7 +129,7 @@ class SetupRunner(object):
raise RuntimeError("Invalid '{}' option given to --build-type. "
.format(config.build_type))
- # Build everything: shiboken2, shiboken2-generator and PySide2.
+ # Build everything: shiboken6, shiboken6-generator and PySide2.
help_requested = '--help' in self.sub_argv or '-h' in self.sub_argv
if help_requested:
self.add_setup_internal_invocation(config.pyside_option_name)
diff --git a/build_scripts/config.py b/build_scripts/config.py
index a69e8fe81..242e39d68 100644
--- a/build_scripts/config.py
+++ b/build_scripts/config.py
@@ -57,10 +57,10 @@ class Config(object):
self.invocation_type = None
# The type of the top-level build.
# all - build shiboken2 module, shiboken2-generator and PySide2
# modules
# shiboken2 - build only shiboken2 module
# shiboken2-generator - build only the shiboken2-generator
# pyside2 - build only PySide2 modules
self.build_type = None
@@ -70,15 +70,15 @@ class Config(object):
# Options that can be given to --build-type and
# --internal-build-type
- self.shiboken_module_option_name = "shiboken2"
- self.shiboken_generator_option_name = "shiboken2-generator"
+ self.shiboken_module_option_name = "shiboken6"
+ self.shiboken_generator_option_name = "shiboken6-generator"
self.pyside_option_name = "pyside2"
# Names to be passed to setuptools.setup() name key,
# so not package name, but rather project name as it appears
# in the wheel name and on PyPi.
- self.shiboken_module_st_name = "shiboken2"
- self.shiboken_generator_st_name = "shiboken2-generator"
+ self.shiboken_module_st_name = "shiboken6"
+ self.shiboken_generator_st_name = "shiboken6-generator"
self.pyside_st_name = "PySide2"
# Used by check_allowed_python_version to validate the
@@ -200,7 +200,7 @@ class Config(object):
setup_kwargs['install_requires'] = ["{}=={}".format(self.shiboken_module_st_name, package_version)]
setup_kwargs['entry_points'] = {
'console_scripts': [
- 'shiboken2 = {}.scripts.shiboken_tool:main'.format(self.package_name()),
+ 'shiboken6 = {}.scripts.shiboken_tool:main'.format(self.package_name()),
]
}
@@ -223,9 +223,9 @@ class Config(object):
changes_filename = 'CHANGES.rst'
if self.is_internal_shiboken_module_build():
- readme_filename = 'README.shiboken2.md'
+ readme_filename = 'README.shiboken6.md'
elif self.is_internal_shiboken_generator_build():
- readme_filename = 'README.shiboken2-generator.md'
+ readme_filename = 'README.shiboken6-generator.md'
elif self.is_internal_pyside_build():
readme_filename = 'README.pyside2.md'
@@ -264,9 +264,9 @@ class Config(object):
dashes.
"""
if self.is_internal_shiboken_module_build():
- return "shiboken2"
+ return "shiboken6"
elif self.is_internal_shiboken_generator_build():
- return "shiboken2_generator"
+ return "shiboken6_generator"
elif self.is_internal_pyside_build():
return "PySide2"
else:
@@ -298,8 +298,8 @@ class Config(object):
the actual module packages are located.
For example when building the shiboken module, setuptools will
- expect to find the "shiboken2" module sources under
- "sources/shiboken2/shibokenmodule".
+ expect to find the "shiboken6" module sources under
+ "sources/shiboken6/shibokenmodule".
This is really just to satisfy some checks in setuptools
build_py command, and if we ever properly implement the develop
@@ -307,7 +307,7 @@ class Config(object):
"""
if self.is_internal_shiboken_module_build():
return {
- self.package_name(): "sources/shiboken2/shibokenmodule"
+ self.package_name(): "sources/shiboken6/shibokenmodule"
}
elif self.is_internal_shiboken_generator_build():
# This is left empty on purpose, because the shiboken
@@ -326,7 +326,7 @@ class Config(object):
:return: A list of directory names under the sources directory.
"""
if self.is_internal_shiboken_module_build() or self.is_internal_shiboken_generator_build():
- return ['shiboken2']
+ return ['shiboken6']
elif self.is_internal_pyside_build():
return ['pyside2', 'pyside-tools']
return None
@@ -371,7 +371,7 @@ class Config(object):
"""
Used to skip certain build rules and output, when we know that
the CMake build of shiboken was already done as part of the
- top-level "all" build when shiboken2-module was built.
+ top-level "all" build when shiboken6-module was built.
"""
return self.is_internal_shiboken_generator_build() and self.is_top_level_build_all()
@@ -57,10 +57,10 @@ class Config(object):
self.invocation_type = None
# The type of the top-level build.
- # all - build shiboken2 module, shiboken2-generator and PySide2
+ # all - build shiboken6 module, shiboken6-generator and PySide2
# modules
@@ -57,10 +57,10 @@ class Config(object):
# modules
- # shiboken2 - build only shiboken2 module
- # shiboken2-generator - build only the shiboken2-generator
+ # shiboken6 - build only shiboken6 module
+ # shiboken6-generator - build only the shiboken6-generator
# pyside2 - build only PySide2 modules
self.build_type = None
diff --git a/build_scripts/main.py b/build_scripts/main.py
index 384ae6785..fb445ea2e 100644
--- a/build_scripts/main.py
+++ b/build_scripts/main.py
@@ -560,7 +560,7 @@ class PysideBuild(_build, DistUtilsCommandMixin):
# Save the shiboken build dir path for clang deployment
# purposes.
- self.shiboken_build_dir = os.path.join(self.build_dir, "shiboken2")
+ self.shiboken_build_dir = os.path.join(self.build_dir, "shiboken6")
self.log_pre_build_info()
@@ -741,11 +741,11 @@ class PysideBuild(_build, DistUtilsCommandMixin):
# If a custom shiboken cmake config directory path was provided, pass it to CMake.
if OPTION["SHIBOKEN_CONFIG_DIR"] and config.is_internal_pyside_build():
if os.path.exists(OPTION["SHIBOKEN_CONFIG_DIR"]):
- log.info("Using custom provided shiboken2 installation: {}"
+ log.info("Using custom provided shiboken6 installation: {}"
.format(OPTION["SHIBOKEN_CONFIG_DIR"]))
- cmake_cmd.append("-DShiboken2_DIR={}".format(OPTION["SHIBOKEN_CONFIG_DIR"]))
+ cmake_cmd.append("-DShiboken6_DIR={}".format(OPTION["SHIBOKEN_CONFIG_DIR"]))
else:
- log.info("Custom provided shiboken2 installation not found. Path given: {}"
+ log.info("Custom provided shiboken6 installation not found. Path given: {}"
.format(OPTION["SHIBOKEN_CONFIG_DIR"]))
if OPTION["MODULE_SUBSET"]:
@@ -821,7 +821,7 @@ class PysideBuild(_build, DistUtilsCommandMixin):
timestamp = get_package_timestamp()
cmake_cmd.append("-DPACKAGE_SETUP_PY_PACKAGE_TIMESTAMP={}".format(timestamp))
- if extension.lower() in ["shiboken2"]:
+ if extension.lower() in ["shiboken6"]:
cmake_cmd.append("-DCMAKE_INSTALL_RPATH_USE_LINK_PATH=yes")
cmake_cmd.append("-DUSE_PYTHON_VERSION=3.6")
@@ -890,7 +890,7 @@ class PysideBuild(_build, DistUtilsCommandMixin):
raise DistutilsSetupError("Error compiling {}".format(extension))
if not OPTION["SKIP_DOCS"]:
- if extension.lower() == "shiboken2":
+ if extension.lower() == "shiboken6":
try:
# Check if sphinx is installed to proceed.
import sphinx
@@ -994,7 +994,7 @@ class PysideBuild(_build, DistUtilsCommandMixin):
def prepare_standalone_clang(self, is_win=False):
"""
Copies the libclang library to the shiboken2-generator
package so that the shiboken executable works.
"""
log.info('Finding path to the libclang shared library.')
@@ -1028,7 +1028,7 @@ class PysideBuild(_build, DistUtilsCommandMixin):
'bin/libclang.dll',
clang_lib_path)
else:
# shiboken2 links against libclang.so.6 or a similarly
# named library.
# If the linked against library is a symlink, resolve
# the symlink once (but not all the way to the real
@@ -1144,9 +1144,9 @@ class PysideRstDocs(Command, DistUtilsCommandMixin):
try:
# Check if sphinx is installed to proceed.
import sphinx
- if self.name == "shiboken2":
+ if self.name == "shiboken6":
log.info("-- Generating Shiboken documentation")
- log.info("-- Documentation directory: 'html/pyside2/shiboken2/'")
+ log.info("-- Documentation directory: 'html/pyside2/shiboken6/'")
elif self.name == "pyside2":
log.info("-- Generating PySide documentation")
log.info("-- Documentation directory: 'html/pyside2/'")
@@ -1154,15 +1154,15 @@ class PysideRstDocs(Command, DistUtilsCommandMixin):
raise DistutilsSetupError("Sphinx not found - aborting")
self.html_dir = "html"
- # creating directories html/pyside2/shiboken2
+ # creating directories html/pyside2/shiboken6
try:
if not os.path.isdir(self.html_dir):
os.mkdir(self.html_dir)
- if self.name == "shiboken2":
+ if self.name == "shiboken6":
out_pyside = os.path.join(self.html_dir, "pyside2")
if not os.path.isdir(out_pyside):
os.mkdir(out_pyside)
- out_shiboken = os.path.join(out_pyside, "shiboken2")
+ out_shiboken = os.path.join(out_pyside, "shiboken6")
if not os.path.isdir(out_shiboken):
os.mkdir(out_shiboken)
self.out_dir = out_shiboken
@@ -1187,7 +1187,7 @@ class PysideRstDocs(Command, DistUtilsCommandMixin):
if self.name == "pyside2":
self.sphinx_src = os.path.join(self.out_dir, "rst")
- elif self.name == "shiboken2":
+ elif self.name == "shiboken6":
self.sphinx_src = self.out_dir
sphinx_cmd = ["sphinx-build", "-b", "html", "-c", self.sphinx_src,
@@ -994,7 +994,7 @@ class PysideBuild(_build, DistUtilsCommandMixin):
def prepare_standalone_clang(self, is_win=False):
"""
- Copies the libclang library to the shiboken2-generator
+ Copies the libclang library to the shiboken6-generator
package so that the shiboken executable works.
"""
@@ -1028,7 +1028,7 @@ class PysideBuild(_build, DistUtilsCommandMixin):
clang_lib_path)
else:
- # shiboken2 links against libclang.so.6 or a similarly
+ # shiboken6 links against libclang.so.6 or a similarly
# named library.
# If the linked against library is a symlink, resolve